@@ -1,21 +1,55 @@
 # -*- coding: utf-8 -*-
+# File generated according to Generator/ClassesRef/DataLinspace.csv
+# WARNING! All changes made in this file will be lost!
+"""Method code available at https://github.com/Eomys/SciDataTool/tree/master/SciDataTool/Methods//DataLinspace
+"""
+
 from os import linesep
-from SciDataTool.Classes._check import check_init_dict, check_var, raise_
-from SciDataTool.Functions.save import save
-from SciDataTool.Classes.Data import Data
+from logging import getLogger
+from ._check import check_var, raise_
+from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
+from .Data import Data
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
 try:
-    from SciDataTool.Methods.DataLinspace.get_values import get_values
+    from ..Methods.DataLinspace.get_values import get_values
 except ImportError as error:
     get_values = error
 
+try:
+    from ..Methods.DataLinspace.get_length import get_length
+except ImportError as error:
+    get_length = error
+
+try:
+    from ..Methods.DataLinspace.get_axis_periodic import get_axis_periodic
+except ImportError as error:
+    get_axis_periodic = error
+
+try:
+    from ..Methods.DataLinspace.has_period import has_period
+except ImportError as error:
+    has_period = error
+
+try:
+    from ..Methods.DataLinspace.get_periodicity import get_periodicity
+except ImportError as error:
+    get_periodicity = error
+
+
+from ._check import InitUnKnowClassError
+
 
 class DataLinspace(Data):
-    """Abstract class for all kinds of data"""
+    """Class for axes defined as linspaces"""
 
     VERSION = 1
+
+    # Check ImportError to remove unnecessary dependencies in unused method
     # cf Methods.DataLinspace.get_values
     if isinstance(get_values, ImportError):
         get_values = property(
@@ -27,8 +61,55 @@ class DataLinspace(Data):
         )
     else:
         get_values = get_values
-    # save method is available in all object
+    # cf Methods.DataLinspace.get_length
+    if isinstance(get_length, ImportError):
+        get_length = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataLinspace method get_length: " + str(get_length)
+                )
+            )
+        )
+    else:
+        get_length = get_length
+    # cf Methods.DataLinspace.get_axis_periodic
+    if isinstance(get_axis_periodic, ImportError):
+        get_axis_periodic = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataLinspace method get_axis_periodic: "
+                    + str(get_axis_periodic)
+                )
+            )
+        )
+    else:
+        get_axis_periodic = get_axis_periodic
+    # cf Methods.DataLinspace.has_period
+    if isinstance(has_period, ImportError):
+        has_period = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataLinspace method has_period: " + str(has_period)
+                )
+            )
+        )
+    else:
+        has_period = has_period
+    # cf Methods.DataLinspace.get_periodicity
+    if isinstance(get_periodicity, ImportError):
+        get_periodicity = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataLinspace method get_periodicity: "
+                    + str(get_periodicity)
+                )
+            )
+        )
+    else:
+        get_periodicity = get_periodicity
+    # save and copy methods are available in all object
     save = save
+    copy = copy
 
     def __init__(
         self,
@@ -36,37 +117,29 @@ class DataLinspace(Data):
         final=None,
         step=None,
         number=None,
-        include_endpoint=False,
+        include_endpoint=True,
+        is_components=False,
         symbol="",
         name="",
         unit="",
-        symmetries={},
-        is_components=False,
+        symmetries=-1,
         init_dict=None,
+        init_str=None,
     ):
-        """Constructor of the class. Can be use in two ways :
+        """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for SciDataTool type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary wiht every properties as keys
+            for SciDataTool type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_str = s) s must be a string
+        s is the file path to load
+
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for SciDataTool Object"""
+
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
-            check_init_dict(
-                init_dict,
-                [
-                    "initial",
-                    "final",
-                    "step",
-                    "number",
-                    "include_endpoint",
-                    "symbol",
-                    "name",
-                    "unit",
-                    "symmetries",
-                    "is_components",
-                ],
-            )
+            assert type(init_dict) is dict
             # Overwrite default value with init_dict content
             if "initial" in list(init_dict.keys()):
                 initial = init_dict["initial"]
@@ -78,6 +151,8 @@ class DataLinspace(Data):
                 number = init_dict["number"]
             if "include_endpoint" in list(init_dict.keys()):
                 include_endpoint = init_dict["include_endpoint"]
+            if "is_components" in list(init_dict.keys()):
+                is_components = init_dict["is_components"]
             if "symbol" in list(init_dict.keys()):
                 symbol = init_dict["symbol"]
             if "name" in list(init_dict.keys()):
@@ -86,9 +161,7 @@ class DataLinspace(Data):
                 unit = init_dict["unit"]
             if "symmetries" in list(init_dict.keys()):
                 symmetries = init_dict["symmetries"]
-            if "is_components" in list(init_dict.keys()):
-                is_components = init_dict["is_components"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         self.initial = initial
         self.final = final
         self.step = step
@@ -103,22 +176,25 @@ class DataLinspace(Data):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
+
         DataLinspace_str = ""
         # Get the properties inherited from Data
-        DataLinspace_str += super(DataLinspace, self).__str__() + linesep
+        DataLinspace_str += super(DataLinspace, self).__str__()
         DataLinspace_str += "initial = " + str(self.initial) + linesep
         DataLinspace_str += "final = " + str(self.final) + linesep
         DataLinspace_str += "step = " + str(self.step) + linesep
         DataLinspace_str += "number = " + str(self.number) + linesep
-        DataLinspace_str += "include_endpoint = " + str(self.include_endpoint)
-        DataLinspace_str += "is_components = " + str(self.is_components)
+        DataLinspace_str += "include_endpoint = " + str(self.include_endpoint) + linesep
+        DataLinspace_str += "is_components = " + str(self.is_components) + linesep
         return DataLinspace_str
 
     def __eq__(self, other):
         """Compare two objects (skip parent)"""
+
         if type(other) != type(self):
             return False
+
         # Check the properties inherited from Data
         if not super(DataLinspace, self).__eq__(other):
             return False
@@ -137,8 +213,8 @@ class DataLinspace(Data):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
+
         # Get the properties inherited from Data
         DataLinspace_dict = super(DataLinspace, self).as_dict()
         DataLinspace_dict["initial"] = self.initial
@@ -147,13 +223,14 @@ class DataLinspace(Data):
         DataLinspace_dict["number"] = self.number
         DataLinspace_dict["include_endpoint"] = self.include_endpoint
         DataLinspace_dict["is_components"] = self.is_components
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         DataLinspace_dict["__class__"] = "DataLinspace"
         return DataLinspace_dict
 
     def _set_None(self):
         """Set all the properties to None (except SciDataTool object)"""
+
         self.initial = None
         self.final = None
         self.step = None
@@ -172,9 +249,14 @@ class DataLinspace(Data):
         check_var("initial", value, "float")
         self._initial = value
 
-    # First value
-    # Type : float
-    initial = property(fget=_get_initial, fset=_set_initial, doc=u"""First value""")
+    initial = property(
+        fget=_get_initial,
+        fset=_set_initial,
+        doc=u"""First value
+
+        :Type: float
+        """,
+    )
 
     def _get_final(self):
         """getter of final"""
@@ -185,9 +267,14 @@ class DataLinspace(Data):
         check_var("final", value, "float")
         self._final = value
 
-    # Last value
-    # Type : float
-    final = property(fget=_get_final, fset=_set_final, doc=u"""Last value""")
+    final = property(
+        fget=_get_final,
+        fset=_set_final,
+        doc=u"""Last value
+
+        :Type: float
+        """,
+    )
 
     def _get_step(self):
         """getter of step"""
@@ -198,9 +285,14 @@ class DataLinspace(Data):
         check_var("step", value, "float")
         self._step = value
 
-    # Step
-    # Type : float
-    step = property(fget=_get_step, fset=_set_step, doc=u"""Step""")
+    step = property(
+        fget=_get_step,
+        fset=_set_step,
+        doc=u"""Step
+
+        :Type: float
+        """,
+    )
 
     def _get_number(self):
         """getter of number"""
@@ -211,9 +303,14 @@ class DataLinspace(Data):
         check_var("number", value, "int")
         self._number = value
 
-    # Number of steps
-    # Type : int
-    number = property(fget=_get_number, fset=_set_number, doc=u"""Number of steps""")
+    number = property(
+        fget=_get_number,
+        fset=_set_number,
+        doc=u"""Number of steps
+
+        :Type: int
+        """,
+    )
 
     def _get_include_endpoint(self):
         """getter of include_endpoint"""
@@ -224,12 +321,13 @@ class DataLinspace(Data):
         check_var("include_endpoint", value, "bool")
         self._include_endpoint = value
 
-    # Boolean indicating if the endpoint must be included
-    # Type : bool
     include_endpoint = property(
         fget=_get_include_endpoint,
         fset=_set_include_endpoint,
-        doc=u"""Boolean indicating if the endpoint must be included""",
+        doc=u"""Boolean indicating if the endpoint must be included
+
+        :Type: bool
+        """,
     )
 
     def _get_is_components(self):
@@ -241,10 +339,11 @@ class DataLinspace(Data):
         check_var("is_components", value, "bool")
         self._is_components = value
 
-    # Boolean indicating if the axis is components
-    # Type : bool
     is_components = property(
         fget=_get_is_components,
         fset=_set_is_components,
-        doc=u"""Boolean indicating if the axis is components""",
+        doc=u"""Boolean inidcating if the axis is components
+
+        :Type: bool
+        """,
     )
