@@ -1,87 +1,125 @@
 # -*- coding: utf-8 -*-
+# File generated according to Generator/ClassesRef/DataND.csv
+# WARNING! All changes made in this file will be lost!
+"""Method code available at https://github.com/Eomys/SciDataTool/tree/master/SciDataTool/Methods//DataND
+"""
+
 from os import linesep
-from SciDataTool.Classes._check import (
-    set_array,
-    check_init_dict,
-    check_var,
-    raise_,
-    check_dimensions,
-)
-from SciDataTool.Functions.save import save
-from SciDataTool.Classes.Data import Data
+from logging import getLogger
+from ._check import set_array, check_var, raise_
+from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
+from .Data import Data
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
 try:
-    from SciDataTool.Methods.DataND.compare_along import compare_along
+    from ..Methods.DataND.compare_along import compare_along
 except ImportError as error:
     compare_along = error
+
 try:
-    from SciDataTool.Methods.DataND.compare_magnitude_along import (
-        compare_magnitude_along,
-    )
+    from ..Methods.DataND.compare_magnitude_along import compare_magnitude_along
 except ImportError as error:
     compare_magnitude_along = error
+
 try:
-    from SciDataTool.Methods.DataND.compare_phase_along import compare_phase_along
+    from ..Methods.DataND.compare_phase_along import compare_phase_along
 except ImportError as error:
     compare_phase_along = error
+
 try:
-    from SciDataTool.Methods.DataND.compress import compress
+    from ..Methods.DataND.compress import compress
 except ImportError as error:
     compress = error
+
 try:
-    from SciDataTool.Methods.DataND.set_Ftparameters import set_Ftparameters
+    from ..Methods.DataND.set_Ftparameters import set_Ftparameters
 except ImportError as error:
     set_Ftparameters = error
+
 try:
-    from SciDataTool.Methods.DataND.comp_axes import comp_axes
+    from ..Methods.DataND.comp_axes import comp_axes
 except ImportError as error:
     comp_axes = error
+
 try:
-    from SciDataTool.Methods.DataND.convert import convert
+    from ..Methods.DataND.convert import convert
 except ImportError as error:
     convert = error
+
 try:
-    from SciDataTool.Methods.DataND.extract_slices import extract_slices
+    from ..Methods.DataND.extract_slices import extract_slices
 except ImportError as error:
     extract_slices = error
+
 try:
-    from SciDataTool.Methods.DataND.extract_slices_fft import extract_slices_fft
+    from ..Methods.DataND.extract_slices_fft import extract_slices_fft
 except ImportError as error:
     extract_slices_fft = error
+
 try:
-    from SciDataTool.Methods.DataND.get_field import get_field
+    from ..Methods.DataND.get_field import get_field
 except ImportError as error:
     get_field = error
+
 try:
-    from SciDataTool.Methods.DataND.interpolate import interpolate
+    from ..Methods.DataND.rebuild_symmetries import rebuild_symmetries
+except ImportError as error:
+    rebuild_symmetries = error
+
+try:
+    from ..Methods.DataND.interpolate import interpolate
 except ImportError as error:
     interpolate = error
+
 try:
-    from SciDataTool.Methods.DataND.get_along import get_along
+    from ..Methods.DataND.get_along import get_along
 except ImportError as error:
     get_along = error
+
 try:
-    from SciDataTool.Methods.DataND.get_magnitude_along import get_magnitude_along
+    from ..Methods.DataND.get_magnitude_along import get_magnitude_along
 except ImportError as error:
     get_magnitude_along = error
+
 try:
-    from SciDataTool.Methods.DataND.get_phase_along import get_phase_along
+    from ..Methods.DataND.get_phase_along import get_phase_along
 except ImportError as error:
     get_phase_along = error
+
 try:
-    from SciDataTool.Methods.DataND.get_harmonics import get_harmonics
+    from ..Methods.DataND.get_harmonics import get_harmonics
 except ImportError as error:
     get_harmonics = error
-from numpy import array, array_equal, squeeze
-from SciDataTool.Classes._check import InitUnKnowClassError
+
+try:
+    from ..Methods.DataND._set_values import _set_values
+except ImportError as error:
+    _set_values = error
+
+try:
+    from ..Methods.DataND.has_period import has_period
+except ImportError as error:
+    has_period = error
+
+try:
+    from ..Methods.DataND.get_axes import get_axes
+except ImportError as error:
+    get_axes = error
+
+
+from numpy import array, array_equal
+from ._check import InitUnKnowClassError
 
 
 class DataND(Data):
-    """Abstract class for physical quantities depending on others"""
+    """Abstract class for fields (time or frequency domain)"""
 
     VERSION = 1
+
     # Check ImportError to remove unnecessary dependencies in unused method
     # cf Methods.DataND.compare_along
     if isinstance(compare_along, ImportError):
@@ -142,9 +180,7 @@ class DataND(Data):
     if isinstance(comp_axes, ImportError):
         comp_axes = property(
             fget=lambda x: raise_(
-                ImportError(
-                    "Can't use DataND method comp_axes: " + str(comp_axes)
-                )
+                ImportError("Can't use DataND method comp_axes: " + str(comp_axes))
             )
         )
     else:
@@ -153,9 +189,7 @@ class DataND(Data):
     if isinstance(convert, ImportError):
         convert = property(
             fget=lambda x: raise_(
-                ImportError(
-                    "Can't use DataND method convert: " + str(convert)
-                )
+                ImportError("Can't use DataND method convert: " + str(convert))
             )
         )
     else:
@@ -176,7 +210,8 @@ class DataND(Data):
         extract_slices_fft = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use DataND method extract_slices_fft: " + str(extract_slices_fft)
+                    "Can't use DataND method extract_slices_fft: "
+                    + str(extract_slices_fft)
                 )
             )
         )
@@ -186,20 +221,28 @@ class DataND(Data):
     if isinstance(get_field, ImportError):
         get_field = property(
             fget=lambda x: raise_(
-                ImportError(
-                    "Can't use DataND method get_field: " + str(get_field)
-                )
+                ImportError("Can't use DataND method get_field: " + str(get_field))
             )
         )
     else:
         get_field = get_field
+    # cf Methods.DataND.rebuild_symmetries
+    if isinstance(rebuild_symmetries, ImportError):
+        rebuild_symmetries = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataND method rebuild_symmetries: "
+                    + str(rebuild_symmetries)
+                )
+            )
+        )
+    else:
+        rebuild_symmetries = rebuild_symmetries
     # cf Methods.DataND.interpolate
     if isinstance(interpolate, ImportError):
         interpolate = property(
             fget=lambda x: raise_(
-                ImportError(
-                    "Can't use DataND method interpolate: " + str(interpolate)
-                )
+                ImportError("Can't use DataND method interpolate: " + str(interpolate))
             )
         )
     else:
@@ -208,9 +251,7 @@ class DataND(Data):
     if isinstance(get_along, ImportError):
         get_along = property(
             fget=lambda x: raise_(
-                ImportError(
-                    "Can't use DataND method get_along: " + str(get_along)
-                )
+                ImportError("Can't use DataND method get_along: " + str(get_along))
             )
         )
     else:
@@ -220,7 +261,8 @@ class DataND(Data):
         get_magnitude_along = property(
             fget=lambda x: raise_(
                 ImportError(
-                    "Can't use DataND method get_magnitude_along: " + str(get_magnitude_along)
+                    "Can't use DataND method get_magnitude_along: "
+                    + str(get_magnitude_along)
                 )
             )
         )
@@ -248,42 +290,64 @@ class DataND(Data):
         )
     else:
         get_harmonics = get_harmonics
-    # save method is available in all object
+    # cf Methods.DataND._set_values
+    if isinstance(_set_values, ImportError):
+        _set_values = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use DataND method _set_values: " + str(_set_values))
+            )
+        )
+    else:
+        _set_values = _set_values
+    # cf Methods.DataND.has_period
+    if isinstance(has_period, ImportError):
+        has_period = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use DataND method has_period: " + str(has_period))
+            )
+        )
+    else:
+        has_period = has_period
+    # cf Methods.DataND.get_axes
+    if isinstance(get_axes, ImportError):
+        get_axes = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use DataND method get_axes: " + str(get_axes))
+            )
+        )
+    else:
+        get_axes = get_axes
+    # save and copy methods are available in all object
     save = save
+    copy = copy
 
     def __init__(
         self,
         axes=None,
-        normalizations={},
-        FTparameters={},
+        normalizations=-1,
+        FTparameters=-1,
         values=None,
         symbol="",
         name="",
         unit="",
-        symmetries={},
+        symmetries=-1,
         init_dict=None,
+        init_str=None,
     ):
-        """Constructor of the class. Can be use in two ways :
+        """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for SciDataTool type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary wiht every properties as keys
+            for SciDataTool type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_str = s) s must be a string
+        s is the file path to load
+
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for SciDataTool Object"""
+
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
-            check_init_dict(
-                init_dict,
-                [
-                    "axes",
-                    "normalizations",
-                    "FTparameters",
-                    "values",
-                    "symbol",
-                    "name",
-                    "unit",
-                    "symmetries",
-                ],
-            )
+            assert type(init_dict) is dict
             # Overwrite default value with init_dict content
             if "axes" in list(init_dict.keys()):
                 axes = init_dict["axes"]
@@ -301,45 +365,11 @@ class DataND(Data):
                 unit = init_dict["unit"]
             if "symmetries" in list(init_dict.keys()):
                 symmetries = init_dict["symmetries"]
-        # Initialisation by argument
-        # axes can be None or a list of Data object
-        axes_list = list()
-        if type(axes) is list:
-            for obj in axes:
-                if obj is None:  # Default value
-                    axes_list.append(Data())
-                elif isinstance(obj, dict):
-                    # Check that the type is correct (including daughter)
-                    class_name = obj.get("__class__")
-                    if class_name not in [
-                        "Data",
-                        "Data1D",
-                        "DataFreq",
-                        "DataLinspace",
-                        "DataND",
-                        "DataTime",
-                    ]:
-                        raise InitUnKnowClassError(
-                            "Unknow class name " + class_name + " in init_dict for axes"
-                        )
-                    # Dynamic import to call the correct constructor
-                    module = __import__(
-                        "SciDataTool.Classes." + class_name, fromlist=[class_name]
-                    )
-                    class_obj = getattr(module, class_name)
-                    axes_list.append(class_obj(init_dict=obj))
-                else:
-                    axes_list.append(obj)
-        elif axes is None:
-            axes_list = list()
-        else:
-            axes_list = axes
+        # Set the properties (value check and convertion are done in setter)
+        self.axes = axes
         self.normalizations = normalizations
         self.FTparameters = FTparameters
-        # values can be None, a ndarray or a list
-        values = check_dimensions(values, axes_list)
-        self.axes = axes_list
-        set_array(self, "values", values)
+        self.values = values
         # Call Data init
         super(DataND, self).__init__(
             symbol=symbol, name=name, unit=unit, symmetries=symmetries
@@ -348,31 +378,29 @@ class DataND(Data):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
+
         DataND_str = ""
         # Get the properties inherited from Data
-        DataND_str += super(DataND, self).__str__() + linesep
-        if len(self.axes) == 0:
-            DataND_str += "axes = []"
-        for ii in range(len(self.axes)):
-            DataND_str += (
-                "axes["
-                + str(ii)
-                + "] = "
-                + str(self.axes[ii].as_dict())
-                + "\n"
-                + linesep
-                + linesep
-            )
+        DataND_str += super(DataND, self).__str__()
+        DataND_str += "axes = " + str(self.axes) + linesep + linesep
         DataND_str += "normalizations = " + str(self.normalizations) + linesep
         DataND_str += "FTparameters = " + str(self.FTparameters) + linesep
-        DataND_str += "values = " + linesep + str(self.values)
+        DataND_str += (
+            "values = "
+            + linesep
+            + str(self.values).replace(linesep, linesep + "\t")
+            + linesep
+            + linesep
+        )
         return DataND_str
 
     def __eq__(self, other):
         """Compare two objects (skip parent)"""
+
         if type(other) != type(self):
             return False
+
         # Check the properties inherited from Data
         if not super(DataND, self).__eq__(other):
             return False
@@ -387,28 +415,31 @@ class DataND(Data):
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
+
         # Get the properties inherited from Data
         DataND_dict = super(DataND, self).as_dict()
-        DataND_dict["axes"] = list()
-        for obj in self.axes:
-            DataND_dict["axes"].append(obj.as_dict())
+        if self.axes is None:
+            DataND_dict["axes"] = None
+        else:
+            DataND_dict["axes"] = list()
+            for obj in self.axes:
+                DataND_dict["axes"].append(obj.as_dict())
         DataND_dict["normalizations"] = self.normalizations
         DataND_dict["FTparameters"] = self.FTparameters
         if self.values is None:
             DataND_dict["values"] = None
         else:
             DataND_dict["values"] = self.values.tolist()
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         DataND_dict["__class__"] = "DataND"
         return DataND_dict
 
     def _set_None(self):
         """Set all the properties to None (except SciDataTool object)"""
-        for obj in self.axes:
-            obj._set_None()
+
+        self.axes = None
         self.normalizations = None
         self.FTparameters = None
         self.values = None
@@ -417,25 +448,33 @@ class DataND(Data):
 
     def _get_axes(self):
         """getter of axes"""
-        for obj in self._axes:
-            if obj is not None:
-                obj.parent = self
+        if self._axes is not None:
+            for obj in self._axes:
+                if obj is not None:
+                    obj.parent = self
         return self._axes
 
     def _set_axes(self, value):
         """setter of axes"""
+        if type(value) is list:
+            for ii, obj in enumerate(value):
+                if type(obj) is dict:
+                    class_obj = import_class(
+                        "SciDataTool.Classes", obj.get("__class__"), "axes"
+                    )
+                    value[ii] = class_obj(init_dict=obj)
+        if value == -1:
+            value = list()
         check_var("axes", value, "[Data]")
         self._axes = value
-        for obj in self._axes:
-            if obj is not None:
-                obj.parent = self
 
-    # List of the Data1D objects corresponding to the axes
-    # Type : [Data]
     axes = property(
         fget=_get_axes,
         fset=_set_axes,
-        doc=u"""List of the Data1D objects corresponding to the axes""",
+        doc=u"""List of the Data1D objects corresponding to the axes
+
+        :Type: [SciDataTool.Classes.Data]
+        """,
     )
 
     def _get_normalizations(self):
@@ -444,15 +483,18 @@ class DataND(Data):
 
     def _set_normalizations(self, value):
         """setter of normalizations"""
+        if type(value) is int and value == -1:
+            value = dict()
         check_var("normalizations", value, "dict")
         self._normalizations = value
 
-    # Normalizations available for the field and its axes
-    # Type : dict
     normalizations = property(
         fget=_get_normalizations,
         fset=_set_normalizations,
-        doc=u"""Normalizations available for the field and its axes""",
+        doc=u"""Normalizations available for the field and its axes
+
+        :Type: dict
+        """,
     )
 
     def _get_FTparameters(self):
@@ -461,33 +503,29 @@ class DataND(Data):
 
     def _set_FTparameters(self, value):
         """setter of FTparameters"""
+        if type(value) is int and value == -1:
+            value = dict()
         check_var("FTparameters", value, "dict")
         self._FTparameters = value
 
-    # Tunable parameters for the Fourier Transforms
-    # Type : dict
     FTparameters = property(
         fget=_get_FTparameters,
         fset=_set_FTparameters,
-        doc=u"""Tunable parameters for the Fourier Transforms""",
+        doc=u"""Tunable parameters for the Fourier Transforms
+
+        :Type: dict
+        """,
     )
 
     def _get_values(self):
         """getter of values"""
         return self._values
 
-    def _set_values(self, value):
-        """setter of values"""
-        if type(value) is list:
-            try:
-                value = squeeze(array(value))
-            except:
-                value = squeeze(value)
-        check_var("values", value, "ndarray")
-        self._values = value
-
-    # Values of the field
-    # Type : ndarray
     values = property(
-        fget=_get_values, fset=_set_values, doc=u"""Values of the field"""
+        fget=_get_values,
+        fset=_set_values,
+        doc=u"""Values of the field
+
+        :Type: ndarray
+        """,
     )
