@@ -1,25 +1,35 @@
 # -*- coding: utf-8 -*-
+# File generated according to Generator/ClassesRef/DataTime.csv
+# WARNING! All changes made in this file will be lost!
+"""Method code available at https://github.com/Eomys/SciDataTool/tree/master/SciDataTool/Methods//DataTime
+"""
+
 from os import linesep
-from SciDataTool.Classes._check import set_array, check_init_dict, check_var, raise_
-from SciDataTool.Functions.save import save
-from SciDataTool.Classes.DataND import DataND
+from logging import getLogger
+from ._check import set_array, check_var, raise_
+from ..Functions.save import save
+from ..Functions.copy import copy
+from ..Functions.load import load_init_dict
+from ..Functions.Load.import_class import import_class
+from .DataND import DataND
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
 try:
-    from SciDataTool.Methods.DataTime.time_to_freq import time_to_freq
+    from ..Methods.DataTime.time_to_freq import time_to_freq
 except ImportError as error:
     time_to_freq = error
+
+
 from numpy import array, array_equal
-from SciDataTool.Classes._check import InitUnKnowClassError
-from SciDataTool.Classes.Data import Data
+from ._check import InitUnKnowClassError
 
 
 class DataTime(DataND):
-    """Class for physical quantities stored in the time/space domain"""
+    """Class for fields defined in time space"""
 
     VERSION = 1
-    # Check ImportError to remove unnecessary dependencies in unused method
+
     # cf Methods.DataTime.time_to_freq
     if isinstance(time_to_freq, ImportError):
         time_to_freq = property(
@@ -31,42 +41,37 @@ class DataTime(DataND):
         )
     else:
         time_to_freq = time_to_freq
-    # save method is available in all object
+    # save and copy methods are available in all object
     save = save
+    copy = copy
 
     def __init__(
         self,
         axes=None,
-        normalizations={},
-        FTparameters={},
+        normalizations=-1,
+        FTparameters=-1,
         values=None,
         symbol="",
         name="",
         unit="",
-        symmetries={},
+        symmetries=-1,
         init_dict=None,
+        init_str=None,
     ):
-        """Constructor of the class. Can be use in two ways :
+        """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
-            for Matrix, None will initialise the property with an empty Matrix
-            for SciDataTool type, None will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary wiht every properties as keys
+            for SciDataTool type, -1 will call the default constructor
+        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_str = s) s must be a string
+        s is the file path to load
+
         ndarray or list can be given for Vector and Matrix
         object or dict can be given for SciDataTool Object"""
+
+        if init_str is not None:  # Load from a file
+            init_dict = load_init_dict(init_str)[1]
         if init_dict is not None:  # Initialisation by dict
-            check_init_dict(
-                init_dict,
-                [
-                    "axes",
-                    "normalizations",
-                    "FTparameters",
-                    "values",
-                    "symbol",
-                    "name",
-                    "unit",
-                    "symmetries",
-                ],
-            )
+            assert type(init_dict) is dict
             # Overwrite default value with init_dict content
             if "axes" in list(init_dict.keys()):
                 axes = init_dict["axes"]
@@ -84,7 +89,7 @@ class DataTime(DataND):
                 unit = init_dict["unit"]
             if "symmetries" in list(init_dict.keys()):
                 symmetries = init_dict["symmetries"]
-        # Initialisation by argument
+        # Set the properties (value check and convertion are done in setter)
         # Call DataND init
         super(DataTime, self).__init__(
             axes=axes,
@@ -100,32 +105,36 @@ class DataTime(DataND):
         # add new properties
 
     def __str__(self):
-        """Convert this objet in a readeable string (for print)"""
+        """Convert this object in a readeable string (for print)"""
+
         DataTime_str = ""
         # Get the properties inherited from DataND
-        DataTime_str += super(DataTime, self).__str__() + linesep
+        DataTime_str += super(DataTime, self).__str__()
         return DataTime_str
 
     def __eq__(self, other):
         """Compare two objects (skip parent)"""
+
         if type(other) != type(self):
             return False
+
         # Check the properties inherited from DataND
         if not super(DataTime, self).__eq__(other):
             return False
         return True
 
     def as_dict(self):
-        """Convert this objet in a json seriable dict (can be use in __init__)
-        """
+        """Convert this object in a json seriable dict (can be use in __init__)"""
+
         # Get the properties inherited from DataND
         DataTime_dict = super(DataTime, self).as_dict()
-        # The class name is added to the dict fordeserialisation purpose
+        # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         DataTime_dict["__class__"] = "DataTime"
         return DataTime_dict
 
     def _set_None(self):
         """Set all the properties to None (except SciDataTool object)"""
+
         # Set to None the properties inherited from DataND
         super(DataTime, self)._set_None()
