@@ -1,7 +1,20 @@
 # -*- coding: utf-8 -*-
 from SciDataTool.Functions import UnitError
 from SciDataTool.Functions.fft_functions import comp_fft_freqs, comp_fft_time
-from numpy import pi, log10, sqrt, square, column_stack, exp, real, imag, cos, sin, abs as np_abs, angle as np_angle
+from numpy import (
+    pi,
+    log10,
+    sqrt,
+    square,
+    column_stack,
+    exp,
+    real,
+    imag,
+    cos,
+    sin,
+    abs as np_abs,
+    angle as np_angle,
+)
 
 # List of the unit symbols, their normalizing value and their dimensions "MLTTempAngleCurrent"
 unit_symbols = [
@@ -130,7 +143,7 @@ def convert(values, unit1, unit2):
 
 def to_dB(values, unit, ref_value=1.0):
     """Converts values into dB normalized with ref_value
-    
+
     Parameters
     ----------
     values: ndarray
@@ -153,7 +166,7 @@ def to_dB(values, unit, ref_value=1.0):
 
 def to_dBA(values, freqs, unit, ref_value=1.0):
     """Converts values into dBA (requires frequency vector)
-    
+
     Parameters
     ----------
     values: array
@@ -174,7 +187,7 @@ def to_dBA(values, freqs, unit, ref_value=1.0):
 
 def dB_to_dBA(values, freqs):
     """Converts values from dB into dBA (requires frequency vector)
-    
+
     Parameters
     ----------
     values: array
@@ -196,8 +209,10 @@ def dB_to_dBA(values, freqs):
         )
     )
     Aweight = 2.0 + 20.0 * log10(RA)
-    Aweight[RA==0] = -100 # replacing -Inf by -100 dB
-    Aweight[values<=0] = 0 # avoiding to increase dB in dBA at frequencies where noise is already null
+    Aweight[RA == 0] = -100  # replacing -Inf by -100 dB
+    Aweight[
+        values <= 0
+    ] = 0  # avoiding to increase dB in dBA at frequencies where noise is already null
     try:
         values += Aweight
         return values
@@ -207,7 +222,7 @@ def dB_to_dBA(values, freqs):
 
 def xyz_to_rphiz(values):
     """Converts axis values from cartesian coordinates into cylindrical coordinates
-    
+
     Parameters
     ----------
     values: array
@@ -216,21 +231,21 @@ def xyz_to_rphiz(values):
     -------
     ndarray of the axis (Nx3)
     """
-    
-    x = values[:,0]
-    y = values[:,1]
-    z = values[:,2]
-    
-    affixe = x + 1j*y
+
+    x = values[:, 0]
+    y = values[:, 1]
+    z = values[:, 2]
+
+    affixe = x + 1j * y
     r = np_abs(affixe)
     phi = (np_angle(affixe) + 2 * pi) % (2 * pi)
-    
+
     return column_stack((r, phi, z))
 
 
 def rphiz_to_xyz(values):
     """Converts axis values from cylindrical coordinates into cartesian coordinates
-    
+
     Parameters
     ----------
     values: array
@@ -239,20 +254,21 @@ def rphiz_to_xyz(values):
     -------
     ndarray of the axis (Nx3)
     """
-    
-    r = values[:,0]
-    phi = values[:,1]
-    z = values[:,2]
-    
-    affixe = r * exp(1j*phi)
+
+    r = values[:, 0]
+    phi = values[:, 1]
+    z = values[:, 2]
+
+    affixe = r * exp(1j * phi)
     x = real(affixe)
     y = imag(affixe)
-    
+
     return column_stack((x, y, z))
 
+
 def xyz_to_rphiz_field(values, phi):
     """Converts field values from cartesian coordinates into cylindrical coordinates
-    
+
     Parameters
     ----------
     values: array
@@ -263,23 +279,23 @@ def xyz_to_rphiz_field(values, phi):
     -------
     ndarray of the field (Nx3)
     """
-    
-    field_x = values[:,0]
-    field_y = values[:,1]
-    field_z = values[:,2]
-    
+
+    field_x = values[:, 0]
+    field_y = values[:, 1]
+    field_z = values[:, 2]
+
     cos_phi = cos(phi)
     sin_phi = sin(phi)
-    
+
     field_r = cos_phi * field_x + sin_phi * field_y
-    field_phi = - sin_phi * field_x + cos_phi * field_y
-    
+    field_phi = -sin_phi * field_x + cos_phi * field_y
+
     return column_stack((field_r, field_phi, field_z))
 
 
 def rphiz_to_xyz_field(values, phi):
     """Converts field values from cylindrical coordinates into cartesian coordinates
-    
+
     Parameters
     ----------
     values: array
@@ -290,17 +306,17 @@ def rphiz_to_xyz_field(values, phi):
     -------
     ndarray of the field (Nx3)
     """
-    
-    field_r = values[:,0]
-    field_phi = values[:,1]
-    field_z = values[:,2]
-    
+
+    field_r = values[:, 0]
+    field_phi = values[:, 1]
+    field_z = values[:, 2]
+
     cos_phi = cos(phi)
     sin_phi = sin(phi)
-    
+
     field_x = cos_phi * field_r - sin_phi * field_phi
     field_y = sin_phi * field_r + cos_phi * field_phi
-    
+
     return column_stack((field_x, field_y, field_z))
 
 
@@ -325,34 +341,38 @@ def wavenumber_to_angle(values):
     is_angle = True
     return comp_fft_time(values, is_angle)
 
+
 def xy_to_rphi(x, y):
-    affixe = x + 1j*y
+    affixe = x + 1j * y
     r = np_abs(affixe)
     phi = (np_angle(affixe) + 2 * pi) % (2 * pi)
-    
+
     return (r, phi)
 
+
 def rphi_to_xy(r, phi):
-    affixe = r * exp(1j*phi)
+    affixe = r * exp(1j * phi)
     x = real(affixe)
     y = imag(affixe)
-    
+
     return (x, y)
 
+
 def cart2pol(field_x, field_y, phi):
     cos_phi = cos(phi)
     sin_phi = sin(phi)
-    
+
     field_r = cos_phi * field_x + sin_phi * field_y
-    field_phi = - sin_phi * field_x + cos_phi * field_y
-    
-    return(field_r, field_phi)
+    field_phi = -sin_phi * field_x + cos_phi * field_y
+
+    return (field_r, field_phi)
+
 
 def pol2cart(field_r, field_phi, phi):
     cos_phi = cos(phi)
     sin_phi = sin(phi)
-    
+
     field_x = cos_phi * field_r - sin_phi * field_phi
     field_y = sin_phi * field_r + cos_phi * field_phi
-    
-    return(field_x, field_y)
+
+    return (field_x, field_y)
