@@ -4,6 +4,7 @@ from SciDataTool.Functions.fft_functions import comp_fft, comp_ifft
 
 from numpy import apply_along_axis
 
+
 def get_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
     """Returns the ndarray of the field, using conversions and symmetries if needed.
     Parameters
@@ -28,13 +29,12 @@ def get_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
     axes_list = read_input_strings(args, axis_data)
     # Extract the requested axes (symmetries + unit)
     axes_list, transforms = self.comp_axes(axes_list)
-    # Get the field with symmetries
+    # Get the field
     values = self.get_field(axes_list)
     # Inverse fft
     if "ifft" in transforms:
         for axis in axes_list:
             if axis.transform == "ifft":
-                print(axis.index)
                 values = apply_along_axis(comp_ifft, axis.index, values)
     # Slices along time/space axes
     values = self.extract_slices(values, axes_list)
@@ -45,6 +45,39 @@ def get_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
                 values = apply_along_axis(comp_fft, axis.index, values)
     # Slices along fft axes
     values = self.extract_slices_fft(values, axes_list)
+    # Rebuild symmetries
+    for axis in axes_list:
+        if axis.transform != "fft" and axis.extension in [
+            "whole",
+            "interval",
+            "oneperiod",
+            "antiperiod",
+            "smallestperiod",
+        ]:
+            if axis.extension == "smallestperiod":
+                is_smallestperiod = True
+                is_oneperiod = False
+                is_antiperiod = False
+            elif axis.extension == "antiperiod":
+                is_smallestperiod = False
+                is_oneperiod = False
+                is_antiperiod = True
+            elif axis.extension == "oneperiod":
+                is_smallestperiod = False
+                is_oneperiod = True
+                is_antiperiod = False
+            else:
+                is_smallestperiod = False
+                is_oneperiod = False
+                is_antiperiod = False
+            values = self.rebuild_symmetries(
+                values,
+                axis.corr_name,
+                axis.index,
+                is_oneperiod=is_oneperiod,
+                is_antiperiod=is_antiperiod,
+                is_smallestperiod=is_smallestperiod,
+            )
     # Interpolate over axis values
     values = self.interpolate(values, axes_list)
     # Conversions
@@ -52,8 +85,13 @@ def get_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
     # Return axes and values
     return_dict = {}
     for axis_requested in axes_list:
-        if axis_requested.extension == "whole" or axis_requested.extension == "interval":
+        if axis_requested.extension in [
+            "whole",
+            "interval",
+            "oneperiod",
+            "antiperiod",
+            "smallestperiod",
+        ]:
             return_dict[axis_requested.name] = axis_requested.values
     return_dict[self.symbol] = values
     return return_dict
-    
