@@ -2,6 +2,7 @@
 from numpy import sum as np_sum
 from SciDataTool.Functions.symmetries import rebuild_symmetries
 
+
 def get_field(self, axes_list):
     """Returns the values of the field (with symmetries and sums).
     Parameters
@@ -15,15 +16,24 @@ def get_field(self, axes_list):
     values: ndarray
         values of the field
     """
-    
+
     values = self.values
     for axis_requested in axes_list:
-        # Rebuild symmetries
-        if axis_requested.corr_name in self.symmetries.keys():
-            values = rebuild_symmetries(
-                values, axis_requested.index, self.symmetries.get(axis_requested.corr_name)
-            )
+        # Rebuild symmetries only for fft case
+        if (
+            axis_requested.transform == "fft"
+            and axis_requested.corr_name in self.symmetries.keys()
+        ):
+            if "antiperiod" in self.symmetries.get(axis_requested.corr_name):
+                values = self.rebuild_symmetries(
+                    values,
+                    axis_requested.corr_name,
+                    axis_requested.index,
+                    is_oneperiod=True,
+                    is_antiperiod=False,
+                )
+
         # Sum over sum axes
         if axis_requested.extension == "sum":
             values = np_sum(values, axis=axis_requested.index)
-    return values
\ No newline at end of file
+    return values
